package com.hzy.project.business.payment.service;

import java.util.List;
import com.hzy.project.business.payment.domain.Payment;

/**
 * 支出Service接口
 * 
 * @author ruoyi
 * @date 2026-01-02
 */
public interface IPaymentService 
{
    /**
     * 查询支出
     * 
     * @param paymentId 支出主键
     * @return 支出
     */
    public Payment selectPaymentByPaymentId(Long paymentId);

    /**
     * 查询支出列表
     * 
     * @param payment 支出
     * @return 支出集合
     */
    public List<Payment> selectPaymentList(Payment payment);

    /**
     * 新增支出
     * 
     * @param payment 支出
     * @return 结果
     */
    public int insertPayment(Payment payment);

    /**
     * 修改支出
     * 
     * @param payment 支出
     * @return 结果
     */
    public int updatePayment(Payment payment);

    /**
     * 批量删除支出
     * 
     * @param paymentIds 需要删除的支出主键集合
     * @return 结果
     */
    public int deletePaymentByPaymentIds(String paymentIds);

    /**
     * 删除支出信息
     * 
     * @param paymentId 支出主键
     * @return 结果
     */
    public int deletePaymentByPaymentId(Long paymentId);
}
